import React from "react";
import { Button } from "@react-components/button";
import { Label } from "@react-components/label";
import { Tag } from "@react-components/tag";
import { createChromaticSection, paramsBuilder, storiesOfBuilder } from "@utils";
import { createSharedStories } from "./shared-stories";
import { isNil } from "lodash";
import styles from "./styles.module.css";

function stories(segment) {
  return storiesOfBuilder(module, createChromaticSection("Button")).segment(segment).parameters(paramsBuilder().canvasLayout({
    width: "80%"
  }).chromaticDelay(100).build()).build();
}

createSharedStories( /*#__PURE__*/React.createElement(Button, null), stories("/standard"));
createSharedStories( /*#__PURE__*/React.createElement(Button, {
  primary: true
}), stories("/primary"));
createSharedStories( /*#__PURE__*/React.createElement(Button, {
  secondary: true
}), stories("/secondary"));
createSharedStories( /*#__PURE__*/React.createElement(Button, {
  positive: true
}), stories("/positive"));
createSharedStories( /*#__PURE__*/React.createElement(Button, {
  negative: true
}), stories("/negative"));
createSharedStories( /*#__PURE__*/React.createElement(Button, {
  link: true
}), stories("/link"));
createSharedStories( /*#__PURE__*/React.createElement(Button, {
  naked: true
}), stories("/naked")).add("coloured", () => /*#__PURE__*/React.createElement("div", {
  className: "flex flex-column"
}, /*#__PURE__*/React.createElement("div", {
  className: "flex mb5"
}, /*#__PURE__*/React.createElement(Button, {
  className: "".concat(styles.button, " mr5"),
  naked: true,
  style: {
    backgroundColor: "#FCD5BC",
    boxShadow: "0px 0px 0px 1px #FCD003 inset"
  }
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  active: true,
  className: "".concat(styles.button, " mr5"),
  naked: true
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  disabled: true,
  className: styles.button,
  naked: true
}, "Button")), /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Button, {
  className: "".concat(styles.button, " mr5"),
  circular: true,
  naked: true,
  style: {
    backgroundColor: "#FCD5BC",
    boxShadow: "0px 0px 0px 1px #FCD003 inset"
  }
}, "Aa"), /*#__PURE__*/React.createElement(Button, {
  active: true,
  className: "".concat(styles.button, " mr5"),
  circular: true,
  naked: true
}, "Aa"), /*#__PURE__*/React.createElement(Button, {
  disabled: true,
  className: styles.button,
  circular: true,
  naked: true
}, "Aa"))));

function setRedBackground(element) {
  if (!isNil(element)) {
    element.classList.add("bg-red");
  }
}

stories().add("fluid", () => /*#__PURE__*/React.createElement("div", {
  className: "flex flex-column"
}, /*#__PURE__*/React.createElement("div", {
  className: "mb5"
}, /*#__PURE__*/React.createElement(Button, {
  fluid: true
}, "Button")), /*#__PURE__*/React.createElement("div", {
  className: "w-10"
}, /*#__PURE__*/React.createElement(Button, {
  fluid: true
}, "Button"))));
stories("/label").add("element ref", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Button, {
  label: /*#__PURE__*/React.createElement(Label, {
    ref: setRedBackground
  }, "6")
}, "Button"))).add("object", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Button, {
  label: {
    content: "6"
  },
  className: "mr5"
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  label: {
    content: "6",
    className: "bg-red"
  },
  className: "mr5"
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  label: {
    content: "6",
    ref: setRedBackground
  }
}, "Button")));
stories("/tag").add("element ref", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Button, {
  tag: /*#__PURE__*/React.createElement(Tag, {
    ref: setRedBackground
  })
}, "Button"))).add("object", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Button, {
  tag: {
    className: "bg-red"
  },
  className: "mr5"
}, "Button"), /*#__PURE__*/React.createElement(Button, {
  tag: {
    ref: setRedBackground
  }
}, "Button")));