import React from "react";
import { Button } from "@react-components/button";
import { CommunicationIcon } from "@react-components/icons";
import { Label } from "@react-components/label";
import { Tag } from "@react-components/tag";
import { createChromaticSection, paramsBuilder, storiesOfBuilder } from "@utils";
import { createSharedStories } from "./shared-stories";
import { isNil } from "lodash";

function stories(segment) {
  return storiesOfBuilder(module, createChromaticSection("Label")).segment(segment).parameters(paramsBuilder().canvasLayout({
    width: "80%"
  }).chromaticDelay(100).build()).build();
}

createSharedStories( /*#__PURE__*/React.createElement(Label, null), stories("/standard"));
createSharedStories( /*#__PURE__*/React.createElement(Label, {
  basic: true
}), stories("/basic"));
createSharedStories( /*#__PURE__*/React.createElement(Label, {
  naked: true
}), stories("/naked")).add("coloured", () => /*#__PURE__*/React.createElement("div", {
  className: "flex flex-column items-start"
}, /*#__PURE__*/React.createElement(Label, {
  naked: true,
  style: {
    backgroundColor: "#FFF6E7",
    color: "var(--marine-500)",
    border: "1px solid #FEE9C3"
  },
  className: "mb5"
}, "Notification Sent"), /*#__PURE__*/React.createElement(Label, {
  circular: true,
  naked: true,
  style: {
    backgroundColor: "#FFF6E7",
    color: "var(--marine-500)",
    border: "1px solid #FEE9C3"
  }
}, "R")));

function setRedBackground(element) {
  if (!isNil(element)) {
    element.classList.add("bg-red");
  }
}

stories("/button").add("element ref", () => /*#__PURE__*/React.createElement(Label, {
  button: /*#__PURE__*/React.createElement(Button, {
    icon: /*#__PURE__*/React.createElement(CommunicationIcon, null),
    className: "bg-red"
  }),
  className: "mr5"
}, "Notification Sent")).add("object", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Label, {
  button: {
    icon: /*#__PURE__*/React.createElement(CommunicationIcon, null)
  },
  className: "mr5"
}, "Notification Sent"), /*#__PURE__*/React.createElement(Label, {
  button: {
    icon: /*#__PURE__*/React.createElement(CommunicationIcon, null),
    className: "bg-red"
  },
  className: "mr5"
}, "Notification Sent"), /*#__PURE__*/React.createElement(Label, {
  button: {
    icon: /*#__PURE__*/React.createElement(CommunicationIcon, null),
    ref: setRedBackground
  }
}, "Notification Sent")));
stories("/tag").add("element ref", () => /*#__PURE__*/React.createElement(Label, {
  tag: /*#__PURE__*/React.createElement(Tag, {
    ref: setRedBackground
  })
}, "Notification Sent")).add("object", () => /*#__PURE__*/React.createElement("div", {
  className: "flex"
}, /*#__PURE__*/React.createElement(Label, {
  tag: {
    className: "bg-red"
  },
  className: "mr5"
}, "Notification Sent"), /*#__PURE__*/React.createElement(Label, {
  tag: {
    ref: setRedBackground
  }
}, "Notification Sent")));