import React from "react";
import { Popup } from "@react-components/popup";
import { PureComponent, createRef } from "react";
import { ResizeObserver } from "@juggle/resize-observer";
import { isNil } from "lodash";
export function RedBox() {
  return /*#__PURE__*/React.createElement("div", {
    className: "w12 h12 bg-red",
    tabIndex: "0"
  });
}
RedBox.displayName = "RedBox";
export class RedBoxTrigger extends PureComponent {
  constructor(...args) {
    super(...args);
    this._containerRef = createRef();
    this._containerResizeObserver = null;

    this.handleContainerSizeChange = entries => {
      const {
        onSizeChange
      } = this.props;

      if (!isNil(onSizeChange)) {
        const dimensions = entries[0].target.getBoundingClientRect();
        onSizeChange({
          width: dimensions.width,
          height: dimensions.height
        });
      }
    };

    this.handleButtonClick = event => {
      const {
        open,
        onOpen,
        onClose
      } = this.props;

      if (!open) {
        onOpen(event);
      } else {
        onClose(event);
      }
    };
  }

  componentDidMount() {
    this._containerResizeObserver = new ResizeObserver(this.handleContainerSizeChange);

    this._containerResizeObserver.observe(this._containerRef.current);
  }

  componentWillUnmount() {
    this._containerResizeObserver.disconnect();
  }

  render() {
    return /*#__PURE__*/React.createElement("button", {
      onClick: this.handleButtonClick,
      type: "button",
      ref: this._containerRef
    }, "Open");
  }

  focus() {
    if (!isNil(this._containerRef.current)) {
      this._containerRef.current.focus();
    }
  }

}
RedBoxTrigger.displayName = "RedBoxTrigger";
export class RedBoxPopup extends PureComponent {
  render() {
    return /*#__PURE__*/React.createElement(Popup, Object.assign({
      trigger: /*#__PURE__*/React.createElement(RedBoxTrigger, null)
    }, this.props), /*#__PURE__*/React.createElement(RedBox, null));
  }

}
RedBoxPopup.displayName = "RedBoxPopup";