import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import { ArgumentError, mergeClasses, throwWhenUnsupportedPropIsProvided } from "../../shared";
import { Dropdown } from "../../dropdown";
import { SelectItem, createSelectItem } from "./item";
import { any, arrayOf, bool, element, func, object, oneOfType, shape, string } from "prop-types";
import { forwardRef } from "react";
import { isArray, isNil } from "lodash";
const UNSUPPORTED_PROPS = ["basic", "button", "compact", "additionLabel", "additionPosition", "allowAdditions", "direction", "floating", "header", "item", "labeled", "openOnFocus", "pointing", "selection", "selectOnBlur", "selectOnNavigation", "simple"];
const ACTION_SHAPE = {
  content: element,
  className: string
};
const propTypes = {
  /**
   * An array of items object shorthands.
   */
  options: arrayOf(any),

  /**
   * A select can have a list of actions after his items.
   */
  actions: arrayOf(shape(ACTION_SHAPE)),

  /**
   * @ignore
   */
  inline: bool,

  /**
   * @ignore
   */
  multiple: bool,

  /**
   * @ignore
   */
  forwardedRef: oneOfType([object, func])
};
const defaultProps = {
  inline: false,
  multiple: false
};

function throwWhenMultipleAndValuesIsNotAnArray({
  multiple,
  defaultValues,
  values
}) {
  if (multiple) {
    if (!isNil(defaultValues) && !isArray(defaultValues)) {
      throw new ArgumentError("@orbit-ui/react-components/select defaultValues must be an array when multiple is true.");
    }

    if (!isNil(values) && !isArray(values)) {
      throw new ArgumentError("@orbit-ui/react-components/select values must be an array when multiple is true.");
    }
  }
}

const renderAction = (_ref, index) => {
  let {
    content,
    key,
    className
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["content", "key", "className"]);

  const classes = mergeClasses(className, "action bg-white o-100");
  return _objectSpread({
    content,
    className: classes,
    disabled: true,
    key: key || index
  }, rest);
};

export function PureSelect(props) {
  const {
    options,
    actions,
    inline,
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["options", "actions", "inline", "forwardedRef"]);

  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, "@orbit-ui/react-components/select");
  throwWhenMultipleAndValuesIsNotAnArray(props);

  const renderOptions = () => {
    const selectOptions = options.map(x => {
      return _objectSpread({}, x, {
        factory: createSelectItem
      });
    });

    if (!isNil(actions)) {
      return [...selectOptions, ...actions.map(renderAction)];
    }

    return selectOptions;
  };

  return /*#__PURE__*/React.createElement(Dropdown, Object.assign({
    options: renderOptions(),
    selection: !inline,
    inline: inline,
    ref: forwardedRef
  }, rest));
}
PureSelect.displayName = "PureSelect";
PureSelect.propTypes = propTypes;
PureSelect.defaultProps = defaultProps;
export const Select = forwardRef((props, ref) => /*#__PURE__*/React.createElement(PureSelect, Object.assign({}, props, {
  forwardedRef: ref
})));
[PureSelect, Select].forEach(x => {
  x.Item = SelectItem;
});