import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { Checkbox } from "../../checkbox";
import { Ref } from "semantic-ui-react";
import { arrayOf, bool, element, func, number, object, oneOf, oneOfType, string } from "prop-types";
import { forwardRef } from "react";
import { isNil } from "lodash"; // Sizes constants are duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise it will not render properly in the docs.

const SIZES = ["small", "medium", "large"];
const DEFAULT_SIZE = "medium"; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise the preset will not render properly in the docs.

const CHECKBOX_PROP_TYPES = {
  /**
   * Whether or not the toggle should autofocus on render.
   */
  autofocus: bool,

  /**
   * Delay before trying to autofocus.
   */
  autofocusDelay: number,

  /**
   * The text associated to the toggle.
   */
  text: string,

  /**
   * A toggle can display icons.
   */
  icons: oneOfType([element, arrayOf(element)]),

  /**
   * A label displayed after the toggle text.
   */
  label: oneOfType([element, object]),

  /**
   * An input can vary in sizes.
   */
  size: oneOf(SIZES),

  /**
   * @ignore
   */
  disabled: bool,

  /**
   * @ignore
   */
  className: string,

  /**
   * @ignore
   */
  forwardedRef: oneOfType([object, func]),

  /**
   * @ignore
   */
  unsupportedProps: arrayOf(string),

  /**
   * @ignore
   */
  unsupportedPropsComponentName: string
}; // Duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise the preset will not render properly in the docs.

const CHECKBOX_DEFAULT_PROPS = {
  autofocus: false,
  size: DEFAULT_SIZE,
  disabled: false,
  unsupportedPropsComponentName: "@orbit-ui/react-components/checkbox"
};
const UNSUPPORTED_PROPS = ["as", "defaultIndeterminate", "indeterminate", "slider", "radio", "type"];
export function PureToggle(props) {
  const {
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["forwardedRef"]);

  const renderWithRef = () => {
    return /*#__PURE__*/React.createElement(Ref, {
      innerRef: forwardedRef
    }, renderToggle());
  };

  const renderToggle = () => {
    return /*#__PURE__*/React.createElement(Checkbox, Object.assign({
      toggle: true,
      unsupportedProps: UNSUPPORTED_PROPS,
      unsupportedPropsComponentName: "@orbit-ui/react-components/toggle"
    }, rest));
  };

  return isNil(forwardedRef) ? renderToggle() : renderWithRef();
}
PureToggle.propTypes = CHECKBOX_PROP_TYPES;
PureToggle.defaultProps = CHECKBOX_DEFAULT_PROPS;
export const Toggle = forwardRef((props, ref) => /*#__PURE__*/React.createElement(PureToggle, Object.assign({}, props, {
  forwardedRef: ref
})));